#!/usr/bin/env bash
#
# Simple script to start jackd
# Adapted from 802.11

# make sure we're in the right directory
DIR="$( cd "$(dirname "$0")" ; pwd -P )"
pushd $DIR

sudo ./performance-hacks.sh

if [ -z "$SAMPLE_RATE" ]; then
    SAMPLE_RATE=48000
fi
if [ -z "$PERIOD" ]; then
    PERIOD=512
fi
if [ -z "$N_PERIODS" ]; then
    N_PERIODS=4
fi

LOGS_DIR="logs"
JACKD_LOG="$LOGS_DIR/jackd.log"

# ensure logs exist
if [ ! -d "$LOGS_DIR" ]; then
    mkdir -p $LOGS_DIR
fi

if [ ! -f "$JACKD_LOG" ]; then
    touch $JACKD_LOG
    chmod o+w $JACKD_LOG
    chmod g+w $JACKD_LOG
fi

# set cleanup
cleanup() {
    echo "killing jackd"
    killall jackd
    exit 0
}
trap 'cleanup' SIGINT

#start jackd
export JACK_NO_AUDIO_RESERVATION=1

echo "starting jackd at $SAMPLE_RATE Hz with $N_PERIODS x $PERIOD samples per buffer..."
su pi -c "jackd -R -P70 -p16 -t2000 -dalsa -d hw:audioinjectorpi -n $N_PERIODS -p $PERIOD -r $SAMPLE_RATE -s -S &> $JACKD_LOG &"

# give jackd some time to start
sleep 3

if pgrep "jackd" >/dev/null 2>&1 ; then
    echo "jackd started."
else
    echo "Could not start jackd; check $JACKD_LOG for details"
    exit -1
fi

popd
